pub fn spawn<A: Actor>(actor: A) -> ActorHandle<A>Expand description
Spawn a root actor with a fresh uid labeled from the actor type on the current proc.
pub fn spawn<A: Actor>(actor: A) -> ActorHandle<A>Spawn a root actor with a fresh uid labeled from the actor type on the current proc.