pub fn spawn_with_label<A: Actor>(label: &str, actor: A) -> ActorHandle<A>Expand description
Spawn a root actor with a fresh uid carrying a display label on the current proc.
pub fn spawn_with_label<A: Actor>(label: &str, actor: A) -> ActorHandle<A>Spawn a root actor with a fresh uid carrying a display label on the current proc.