pub fn spawn_with_uid<A: Actor>(uid: Uid, actor: A) -> Result<ActorHandle<A>>Expand description
Spawn a root actor using an explicit uid on the current proc.
pub fn spawn_with_uid<A: Actor>(uid: Uid, actor: A) -> Result<ActorHandle<A>>Spawn a root actor using an explicit uid on the current proc.