register_spawnable

Macro register_spawnable 

macro_rules! register_spawnable {
    ($actor:ty) => { ... };
}
Register an actor type so that it can be spawned remotely. The actor type must implement typeuri::Named, which will be used to identify the actor globally.

Example:

struct MyActor { ... }

register_spawnable!(MyActor);